rpaframework-recognition
========================

This library enablous various recognition features with `RPA Framework`_
libraries, such as image template matching.

.. _RPA Framework: https://rpaframework.org
